/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.mockvehicledataservice;

import java.awt.Color;
import java.util.ArrayList;
import java.util.List;
import javax.swing.ImageIcon;
import nl.cloudfarming.client.fleet.machine.MachineDataService.Model;
import nl.cloudfarming.client.fleet.machine.MachineDataService.StepInfo;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.MachineProperty;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.vehicle.VehicleDataService;
import org.openide.util.ImageUtilities;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Wytse Visser
 */
@ServiceProvider(service = VehicleDataService.class)
public class MockFendtDataService implements VehicleDataService {

    List<Model> models = new ArrayList<>();

    public MockFendtDataService() {
        String tractorType = "Tractor";
        String brand = "Fendt";

        Model model = new Model(tractorType, brand, "F100");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        model.putProperty(Machine.PROP_IMAGE, loadImage());
        models.add(model);

        model = new Model(tractorType, brand, "F200a");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        model = new Model(tractorType, brand, "F200b");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        model = new Model(tractorType, brand, "F300-1");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        model = new Model(tractorType, brand, "F300-2");
        model.putProperty(Vehicle.PROP_HORSEPOWER, 150);
        model.putProperty(Vehicle.PROP_FUELTANKCAPACITY, 300);
        model.putProperty(Vehicle.PROP_DISPLACEMENT, 7.0);
        models.add(model);

        StepInfo step3 = new StepInfo("Fendt step #3");
        step3.addProperty(new MachineProperty(Integer.class, "Integer property", 4));
        step3.addProperty(new MachineProperty(Boolean.class, "Boolean property", true));
        step3.addProperty(new MachineProperty(Color.class, "Color property", Color.GREEN));

        MachineProperty dropdownProp = new MachineProperty(String.class, "Dropdown property", "C");
        dropdownProp.setPossibleValues(new String[]{
                    "A",
                    "B",
                    "C",
                    "D"});
        step3.addProperty(dropdownProp);

        for (Model m : models) {
            m.addAdditionalStep(step3);
        }
    }

    @Override
    public List<Model> getModels() {
        return models;
    }
    
    private ImageIcon loadImage() {
        return ImageUtilities.loadImageIcon("nl/cloudfarming/client/mockvehicledataservice/fendt.jpg", true);
    }
}